retain property
Whether the permission should be retained beyond the lifetime of a page currently being displayed by a WebView
The default value is false.
Implementation
bool retain;
Whether the permission should be retained beyond the lifetime of a page currently being displayed by a WebView
The default value is false.
bool retain;